CountScoreConsumer
==================

.. currentmodule:: pykeen.predict

.. autoclass:: CountScoreConsumer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CountScoreConsumer.__call__

   .. rubric:: Methods Documentation

   .. automethod:: __call__
